pub trait RandomizedMultipartSignerMut<S> {
// Required method
fn try_multipart_sign_with_rng<R: TryCryptoRng + ?Sized>(
&mut self,
rng: &mut R,
msg: &[&[u8]],
) -> Result<S, Error>;
// Provided method
fn multipart_sign_with_rng<R: CryptoRng + ?Sized>(
&mut self,
rng: &mut R,
msg: &[&[u8]],
) -> S { ... }
}Expand description
Equivalent of RandomizedSignerMut but the message is provided in non-contiguous byte slices.
Required Methods
Sourcefn try_multipart_sign_with_rng<R: TryCryptoRng + ?Sized>(
&mut self,
rng: &mut R,
msg: &[&[u8]],
) -> Result<S, Error>
fn try_multipart_sign_with_rng<R: TryCryptoRng + ?Sized>( &mut self, rng: &mut R, msg: &[&[u8]], ) -> Result<S, Error>
Equivalent of RandomizedSignerMut::try_sign_with_rng() but the message is provided in
non-contiguous byte slices.
Errors
Signing can fail, e.g. if the number of time periods allowed by the current key is exceeded,
or if the provided rng experiences an internal failure.
Provided Methods
Sourcefn multipart_sign_with_rng<R: CryptoRng + ?Sized>(
&mut self,
rng: &mut R,
msg: &[&[u8]],
) -> S
fn multipart_sign_with_rng<R: CryptoRng + ?Sized>( &mut self, rng: &mut R, msg: &[&[u8]], ) -> S
Equivalent of RandomizedSignerMut::sign_with_rng() but the message is provided in
non-contiguous byte slices.
Panics
In the event of a signing error.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.